##!/bin/bash
#
# build.sh - build all binaries for the project, and flash it
# 

# as documented in 
#   https://docs.zephyrproject.org/latest/develop/west/sign.html#mcuboot-imgtool

# the mcuboot process is described in:
#   https://docs.zephyrproject.org/latest/services/device_mgmt/dfu.html#dfu

# choose for which board to build:
export BOARD="sg1500"
#BOARD="nrf9160dk_nrf9160"

# initialize the build environment:
. ./build_env.sh

# this simplistic script must be executed from the script location:
cd $(dirname $0)

if [ "$1" == "--debug" ];
then
	set -x
	shift
fi

# = build (using the environment setup =

echo
echo "= build ="

# build with secure bootloader (NSIB) and upgradeable bootloader (mcuboot)
# west uses the NSIB from ncs/<env>/nrf/samples/bootloader and
# the mcboot from bootloader/mcuboot/boot/zephyr
# building is automaticaly done using the west build.
# minimizing the memory footprint can be done using specific config files
# also see: https://devzone.nordicsemi.com/f/nordic-q-a/61272/updatable-bootloader-for-nrf9160

# -DCONFIG_SECURE_BOOT=y \                          # the immutable bootloader NSIB
# -DCONFIG_BOOTLOADER_MCUBOOT=y \                   # the upgradeable bootloader
# -DCONFIG_BUILD_S1_VARIANT=y\                      # build for both upgradeable bootloader slots (mcuboot)
# -Db0_CONF_FILE=prj_minimal.conf \
# -Dmcuboot_CONF_FILE=prj_minimal.conf \            # reduce bootloader image size
# -Dmcuboot_OVERLAY_CONFIG=external_crypto.conf     # mcuboot uses crypto function from NSIB
# -Dmcuboot_CONFIG_BOOT_SIGNATURE_KEY_FILE=\"bootloader/mcuboot/root-rsa-2048.pem\" \
# -DPM_STATIC_YML_FILE=\"${BUILD_ROOT}/SG1500-board-tester/pm_static.yml\" \
! west build --build-dir build/SG1500-board-tester --board ${BOARD}_ns SG1500-board-tester --pristine -- \
	-DCONFIG_SECURE_BOOT=y \
	-DCONFIG_BOOTLOADER_MCUBOOT=y \
	-Db0_CONF_FILE=prj_minimal.conf \
	-Dmcuboot_CONF_FILE=/home/maarten/workspace/avic/fw/spikes/legiobox/mcuboot_prj_minimal.conf \
	-DCONF_FILE:STRING="${BUILD_ROOT}/SG1500-board-tester/prj.conf" \
    && exit

# memory report:
west build -t partition_manager_report --build-dir build/SG1500-board-tester --board ${BOARD}_ns SG1500-board-tester


# flash (using the build results)

echo
echo "= flash device ="
west flash --erase -d build/SG1500-board-tester

echo "= ready ="
